package com.ruoyi.powerdistribution.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.powerdistribution.domain.PdmReportAppointmentWeek;
import com.ruoyi.powerdistribution.service.IPdmReportAppointmentWeekService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 履职周统计Controller
 *
 * @author ruoyi
 * @date 2024-11-29
 */
@RestController
@RequestMapping("/power/appointment/week")
public class PdmReportAppointmentWeekController extends BaseController
{
    @Autowired
    private IPdmReportAppointmentWeekService pdmReportAppointmentWeekService;

    /**
     * 查询履职周统计列表
     */
    @PreAuthorize("@ss.hasPermi('system:week:list')")
    @GetMapping("/list")
    public TableDataInfo list(PdmReportAppointmentWeek pdmReportAppointmentWeek)
    {
        startPage();
        List<PdmReportAppointmentWeek> list = pdmReportAppointmentWeekService.selectPdmReportAppointmentWeekList(pdmReportAppointmentWeek);
        return getDataTable(list);
    }

    /**
     * 导出履职周统计列表
     */
    @PreAuthorize("@ss.hasPermi('system:week:export')")
    @Log(title = "履职周统计", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PdmReportAppointmentWeek pdmReportAppointmentWeek)
    {
        List<PdmReportAppointmentWeek> list = pdmReportAppointmentWeekService.selectPdmReportAppointmentWeekList(pdmReportAppointmentWeek);
        ExcelUtil<PdmReportAppointmentWeek> util = new ExcelUtil<PdmReportAppointmentWeek>(PdmReportAppointmentWeek.class);
        util.exportExcel(response, list, "履职周统计数据");
    }

    /**
     * 获取履职周统计详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:week:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(pdmReportAppointmentWeekService.selectPdmReportAppointmentWeekById(id));
    }

    /**
     * 新增履职周统计
     */
    @PreAuthorize("@ss.hasPermi('system:week:add')")
    @Log(title = "履职周统计", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PdmReportAppointmentWeek pdmReportAppointmentWeek)
    {
        return toAjax(pdmReportAppointmentWeekService.insertPdmReportAppointmentWeek(pdmReportAppointmentWeek));
    }

    /**
     * 修改履职周统计
     */
    @PreAuthorize("@ss.hasPermi('system:week:edit')")
    @Log(title = "履职周统计", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PdmReportAppointmentWeek pdmReportAppointmentWeek)
    {
        return toAjax(pdmReportAppointmentWeekService.updatePdmReportAppointmentWeek(pdmReportAppointmentWeek));
    }

    /**
     * 删除履职周统计
     */
    @PreAuthorize("@ss.hasPermi('system:week:remove')")
    @Log(title = "履职周统计", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(pdmReportAppointmentWeekService.deletePdmReportAppointmentWeekByIds(ids));
    }
}
