package com.ruoyi.powerdistribution.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.powerdistribution.domain.PdmReportIllegalDay;
import com.ruoyi.powerdistribution.service.IPdmReportIllegalDayService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 违章日统计Controller
 *
 * @author ruoyi
 * @date 2024-11-28
 */
@RestController
@RequestMapping("/power/illegal")
public class PdmReportIllegalDayController extends BaseController
{
    @Autowired
    private IPdmReportIllegalDayService pdmReportIllegalDayService;

    /**
     * 查询违章日统计列表
     */
    @PreAuthorize("@ss.hasPermi('system:day:list')")
    @GetMapping("/list")
    public TableDataInfo list(PdmReportIllegalDay pdmReportIllegalDay)
    {
        startPage();
        List<PdmReportIllegalDay> list = pdmReportIllegalDayService.selectPdmReportIllegalDayList(pdmReportIllegalDay);
        return getDataTable(list);
    }

    /**
     * 导出违章日统计列表
     */
    @PreAuthorize("@ss.hasPermi('system:day:export')")
    @Log(title = "违章日统计", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PdmReportIllegalDay pdmReportIllegalDay)
    {
        List<PdmReportIllegalDay> list = pdmReportIllegalDayService.selectPdmReportIllegalDayList(pdmReportIllegalDay);
        ExcelUtil<PdmReportIllegalDay> util = new ExcelUtil<PdmReportIllegalDay>(PdmReportIllegalDay.class);
        util.exportExcel(response, list, "违章日统计数据");
    }

    /**
     * 获取违章日统计详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:day:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(pdmReportIllegalDayService.selectPdmReportIllegalDayById(id));
    }

    /**
     * 新增违章日统计
     */
    @PreAuthorize("@ss.hasPermi('system:day:add')")
    @Log(title = "违章日统计", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PdmReportIllegalDay pdmReportIllegalDay)
    {
        return toAjax(pdmReportIllegalDayService.insertPdmReportIllegalDay(pdmReportIllegalDay));
    }

    /**
     * 修改违章日统计
     */
    @PreAuthorize("@ss.hasPermi('system:day:edit')")
    @Log(title = "违章日统计", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PdmReportIllegalDay pdmReportIllegalDay)
    {
        return toAjax(pdmReportIllegalDayService.updatePdmReportIllegalDay(pdmReportIllegalDay));
    }

    /**
     * 删除违章日统计
     */
    @PreAuthorize("@ss.hasPermi('system:day:remove')")
    @Log(title = "违章日统计", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(pdmReportIllegalDayService.deletePdmReportIllegalDayByIds(ids));
    }
}
