package com.ruoyi.powerdistribution.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.powerdistribution.domain.PdmReportPlanDay;
import com.ruoyi.powerdistribution.service.IPdmReportPlanDayService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 工作计划日统计Controller
 *
 * @author ruoyi
 * @date 2024-11-28
 */
@RestController
@RequestMapping("/power/plan")
public class PdmReportPlanDayController extends BaseController
{
    @Autowired
    private IPdmReportPlanDayService pdmReportPlanDayService;

    /**
     * 查询工作计划日统计列表
     */

    @GetMapping("/list")
    public TableDataInfo list(PdmReportPlanDay pdmReportPlanDay)
    {
        startPage();
        List<PdmReportPlanDay> list = pdmReportPlanDayService.selectPdmReportPlanDayList(pdmReportPlanDay);
        return getDataTable(list);
    }

    /**
     * 导出工作计划日统计列表
     */
    @PreAuthorize("@ss.hasPermi('system:day:export')")
    @Log(title = "工作计划日统计", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PdmReportPlanDay pdmReportPlanDay)
    {
        List<PdmReportPlanDay> list = pdmReportPlanDayService.selectPdmReportPlanDayList(pdmReportPlanDay);
        ExcelUtil<PdmReportPlanDay> util = new ExcelUtil<PdmReportPlanDay>(PdmReportPlanDay.class);
        util.exportExcel(response, list, "工作计划日统计数据");
    }

    /**
     * 获取工作计划日统计详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:day:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(pdmReportPlanDayService.selectPdmReportPlanDayById(id));
    }

    /**
     * 新增工作计划日统计
     */
    @PreAuthorize("@ss.hasPermi('system:day:add')")
    @Log(title = "工作计划日统计", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PdmReportPlanDay pdmReportPlanDay)
    {
        return toAjax(pdmReportPlanDayService.insertPdmReportPlanDay(pdmReportPlanDay));
    }

    /**
     * 修改工作计划日统计
     */
    @PreAuthorize("@ss.hasPermi('system:day:edit')")
    @Log(title = "工作计划日统计", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PdmReportPlanDay pdmReportPlanDay)
    {
        return toAjax(pdmReportPlanDayService.updatePdmReportPlanDay(pdmReportPlanDay));
    }

    /**
     * 删除工作计划日统计
     */
    @PreAuthorize("@ss.hasPermi('system:day:remove')")
    @Log(title = "工作计划日统计", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(pdmReportPlanDayService.deletePdmReportPlanDayByIds(ids));
    }
}
