package com.ruoyi.powerdistribution.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.powerdistribution.domain.PdmReportPlanNextDay;
import com.ruoyi.powerdistribution.service.IPdmReportPlanNextDayService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 明日工作计划Controller
 *
 * @author ruoyi
 * @date 2024-11-28
 */
@RestController
@RequestMapping("/power/next")
public class PdmReportPlanNextDayController extends BaseController
{
    @Autowired
    private IPdmReportPlanNextDayService pdmReportPlanNextDayService;

    /**
     * 查询明日工作计划列表
     */
    @PreAuthorize("@ss.hasPermi('system:day:list')")
    @GetMapping("/list")
    public TableDataInfo list(PdmReportPlanNextDay pdmReportPlanNextDay)
    {
        startPage();
        List<PdmReportPlanNextDay> list = pdmReportPlanNextDayService.selectPdmReportPlanNextDayList(pdmReportPlanNextDay);
        return getDataTable(list);
    }

    /**
     * 导出明日工作计划列表
     */
    @PreAuthorize("@ss.hasPermi('system:day:export')")
    @Log(title = "明日工作计划", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PdmReportPlanNextDay pdmReportPlanNextDay)
    {
        List<PdmReportPlanNextDay> list = pdmReportPlanNextDayService.selectPdmReportPlanNextDayList(pdmReportPlanNextDay);
        ExcelUtil<PdmReportPlanNextDay> util = new ExcelUtil<PdmReportPlanNextDay>(PdmReportPlanNextDay.class);
        util.exportExcel(response, list, "明日工作计划数据");
    }

    /**
     * 获取明日工作计划详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:day:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(pdmReportPlanNextDayService.selectPdmReportPlanNextDayById(id));
    }

    /**
     * 新增明日工作计划
     */
    @PreAuthorize("@ss.hasPermi('system:day:add')")
    @Log(title = "明日工作计划", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PdmReportPlanNextDay pdmReportPlanNextDay)
    {
        return toAjax(pdmReportPlanNextDayService.insertPdmReportPlanNextDay(pdmReportPlanNextDay));
    }

    /**
     * 修改明日工作计划
     */
    @PreAuthorize("@ss.hasPermi('system:day:edit')")
    @Log(title = "明日工作计划", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PdmReportPlanNextDay pdmReportPlanNextDay)
    {
        return toAjax(pdmReportPlanNextDayService.updatePdmReportPlanNextDay(pdmReportPlanNextDay));
    }

    /**
     * 删除明日工作计划
     */
    @PreAuthorize("@ss.hasPermi('system:day:remove')")
    @Log(title = "明日工作计划", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(pdmReportPlanNextDayService.deletePdmReportPlanNextDayByIds(ids));
    }
}
