package com.ruoyi.powerdistribution.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.powerdistribution.domain.PdmReportPlanNextWeek;
import com.ruoyi.powerdistribution.service.IPdmReportPlanNextWeekService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 下周工作计划统计Controller
 *
 * @author ruoyi
 * @date 2024-11-29
 */
@RestController
@RequestMapping("/power/next/week")
public class PdmReportPlanNextWeekController extends BaseController
{
    @Autowired
    private IPdmReportPlanNextWeekService pdmReportPlanNextWeekService;

    /**
     * 查询下周工作计划统计列表
     */
    @PreAuthorize("@ss.hasPermi('system:week:list')")
    @GetMapping("/list")
    public TableDataInfo list(PdmReportPlanNextWeek pdmReportPlanNextWeek)
    {
        startPage();
        List<PdmReportPlanNextWeek> list = pdmReportPlanNextWeekService.selectPdmReportPlanNextWeekList(pdmReportPlanNextWeek);
        return getDataTable(list);
    }

    /**
     * 导出下周工作计划统计列表
     */
    @PreAuthorize("@ss.hasPermi('system:week:export')")
    @Log(title = "下周工作计划统计", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PdmReportPlanNextWeek pdmReportPlanNextWeek)
    {
        List<PdmReportPlanNextWeek> list = pdmReportPlanNextWeekService.selectPdmReportPlanNextWeekList(pdmReportPlanNextWeek);
        ExcelUtil<PdmReportPlanNextWeek> util = new ExcelUtil<PdmReportPlanNextWeek>(PdmReportPlanNextWeek.class);
        util.exportExcel(response, list, "下周工作计划统计数据");
    }

    /**
     * 获取下周工作计划统计详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:week:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(pdmReportPlanNextWeekService.selectPdmReportPlanNextWeekById(id));
    }

    /**
     * 新增下周工作计划统计
     */
    @PreAuthorize("@ss.hasPermi('system:week:add')")
    @Log(title = "下周工作计划统计", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PdmReportPlanNextWeek pdmReportPlanNextWeek)
    {
        return toAjax(pdmReportPlanNextWeekService.insertPdmReportPlanNextWeek(pdmReportPlanNextWeek));
    }

    /**
     * 修改下周工作计划统计
     */
    @PreAuthorize("@ss.hasPermi('system:week:edit')")
    @Log(title = "下周工作计划统计", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PdmReportPlanNextWeek pdmReportPlanNextWeek)
    {
        return toAjax(pdmReportPlanNextWeekService.updatePdmReportPlanNextWeek(pdmReportPlanNextWeek));
    }

    /**
     * 删除下周工作计划统计
     */
    @PreAuthorize("@ss.hasPermi('system:week:remove')")
    @Log(title = "下周工作计划统计", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(pdmReportPlanNextWeekService.deletePdmReportPlanNextWeekByIds(ids));
    }
}
