package com.ruoyi.powerdistribution.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.powerdistribution.domain.PdmReportPlanWeek;
import com.ruoyi.powerdistribution.service.IPdmReportPlanWeekService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 工作计划完成情况周统计Controller
 *
 * @author ruoyi
 * @date 2024-11-29
 */
@RestController
@RequestMapping("/power/plan/week")
public class PdmReportPlanWeekController extends BaseController
{
    @Autowired
    private IPdmReportPlanWeekService pdmReportPlanWeekService;

    /**
     * 查询工作计划完成情况周统计列表
     */
    @PreAuthorize("@ss.hasPermi('system:week:list')")
    @GetMapping("/list")
    public TableDataInfo list(PdmReportPlanWeek pdmReportPlanWeek)
    {
        startPage();
        List<PdmReportPlanWeek> list = pdmReportPlanWeekService.selectPdmReportPlanWeekList(pdmReportPlanWeek);
        return getDataTable(list);
    }

    /**
     * 导出工作计划完成情况周统计列表
     */
    @PreAuthorize("@ss.hasPermi('system:week:export')")
    @Log(title = "工作计划完成情况周统计", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PdmReportPlanWeek pdmReportPlanWeek)
    {
        List<PdmReportPlanWeek> list = pdmReportPlanWeekService.selectPdmReportPlanWeekList(pdmReportPlanWeek);
        ExcelUtil<PdmReportPlanWeek> util = new ExcelUtil<PdmReportPlanWeek>(PdmReportPlanWeek.class);
        util.exportExcel(response, list, "工作计划完成情况周统计数据");
    }

    /**
     * 获取工作计划完成情况周统计详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:week:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(pdmReportPlanWeekService.selectPdmReportPlanWeekById(id));
    }

    /**
     * 新增工作计划完成情况周统计
     */
    @PreAuthorize("@ss.hasPermi('system:week:add')")
    @Log(title = "工作计划完成情况周统计", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PdmReportPlanWeek pdmReportPlanWeek)
    {
        return toAjax(pdmReportPlanWeekService.insertPdmReportPlanWeek(pdmReportPlanWeek));
    }

    /**
     * 修改工作计划完成情况周统计
     */
    @PreAuthorize("@ss.hasPermi('system:week:edit')")
    @Log(title = "工作计划完成情况周统计", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PdmReportPlanWeek pdmReportPlanWeek)
    {
        return toAjax(pdmReportPlanWeekService.updatePdmReportPlanWeek(pdmReportPlanWeek));
    }

    /**
     * 删除工作计划完成情况周统计
     */
    @PreAuthorize("@ss.hasPermi('system:week:remove')")
    @Log(title = "工作计划完成情况周统计", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(pdmReportPlanWeekService.deletePdmReportPlanWeekByIds(ids));
    }
}
